<?php
/*
Plugin Name: WP Share It Now - Lite
Plugin URI: http://yourimhelper.com/plugin_uri
Description: Plugin that can be used to create the fastest your social media campaign
Version: 1.1
Author: <a href="http://yourimhelper.com/chris_jenkins" target="_blank">Chris Jenkins</a> &amp; <a href="http://yourimhelper.com/plugins_team" target="_blank">The PluginsForYou.com Team</a>
Author URI: http://yourimhelper.com/plugin_author_uri 
*/

/*  
    LICENSE: This source file to be part of a system developed by WhiteLabelPlugins.com. 
    All copyrights use this file and the code in it owned by WhiteLabelPlugins.com. 
    It is strictly forbidden to use, copy, modify or distribute this file and 
    the code in it without the permission of the developer.
*/

//Change this value for rebranding plugin
define( 'IPSITNO_TITLE', 'WP Share It Now - Lite' );
define( 'IPSITNO_FILE', __FILE__ );
define( 'IPSITNO_PATH', plugin_dir_path( __FILE__ ) );
define( 'IPSITNO_BASE_URL', plugin_dir_url( __FILE__ ) );

require_once( IPSITNO_PATH . "app/setting.php" );
require_once( IPSITNO_PATH . "app/ajax.php" );
require_once( IPSITNO_PATH . "app/db.php" );
require_once( IPSITNO_PATH . "app/font.php" );
require_once( IPSITNO_PATH . "app/form.php" );
require_once( IPSITNO_PATH . "app/model.php" );
require_once( IPSITNO_PATH . "app/list.php" );
require_once( IPSITNO_PATH . "app/list-coupon.php" );
require_once( IPSITNO_PATH . "app/admin.php" );
require_once( IPSITNO_PATH . "app/admin-coupon.php" );
require_once( IPSITNO_PATH . "app/shortcode.php" );
require_once( IPSITNO_PATH . "app/faicon.php" );
require_once( IPSITNO_PATH . "app/factory.php" );

/**
 * Main class
 */
if ( ! class_exists( 'IPSitno' )) {

    class IPSitno
    {
        /**
         * Setup Plugin
         */
        public static function setup()
        {
            $hook = sanitize_title( IPSITNO_TITLE );
            
            //Register admin menu
            add_action( 'admin_menu', array( __CLASS__, 'add_admin_menu' ) );
            
            //Plugin init
            add_action( 'admin_init', array( __CLASS__, 'admin_init' ) );
            
            //Activate plugin
            register_activation_hook( __FILE__, array( __CLASS__, 'install' ) );
            
            //Hook for plugin loaded
            add_action( 'plugins_loaded', array( __CLASS__, 'update_db' ) );
            
            // Add meta box option
            add_action( 'add_meta_boxes', array( __CLASS__, 'add_meta_box' ) );
            add_action( 'save_post', array( __CLASS__, 'save_page_share' ) );
            
            //Add share object to site
            add_action( 'wp_footer', array( __CLASS__, 'factory' ) );
            
            //Add Editor Button
            add_action( 'admin_init', array( __CLASS__, 'add_editor_button' ) );
            
            //Add Editor Dialog
            add_action( 'tiny_mce_preload_dialogs', array( __CLASS__, 'create_editor' ) );
            add_action( 'after_wp_tiny_mce', array( __CLASS__, 'create_editor' ) );
            
            //Add Shortcode
            add_shortcode( 'wp-share-coupon', array( __CLASS__, 'shortcode' ) );
            
            //Add admin style & script
            add_action( 'admin_print_styles', array( __CLASS__, 'admin_style_global' ), 1000 );
            add_action( 'admin_print_styles-toplevel_page_ipsitno', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipsitno-add', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipsitno-setting', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipsitno-coupons', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipsitno-users', array( __CLASS__, 'admin_style' ), 1000 );
            
            add_action( 'admin_print_scripts-toplevel_page_ipsitno', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipsitno-add', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipsitno-setting', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipsitno-coupons', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipsitno-users', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts', array( __CLASS__, 'global_admin_script' ), 1100 );
            
            //Front style & script
            add_action('wp_head', array( __CLASS__, 'public_style' ) );
            
            if ( ! is_admin() ) {
                add_action('wp_enqueue_scripts', array( __CLASS__, 'public_script' ), 10 );
            }
        }
        
        /**
         * Add administrator menu
         *
         * @return void
         */
        public static function add_admin_menu()
        {
            add_menu_page( 
                IPSITNO_TITLE, 
                IPSITNO_TITLE, 
                'ipsitno_manage', 
                'ipsitno',
                array( __CLASS__, 'admin' ), 
                plugin_dir_url( __FILE__ ) . 'img/menu_icon.png'
            );
            add_submenu_page( 
                'ipsitno',
                __( 'Dashboard', 'wp_share_it_now' ), 
                __( 'Dashboard', 'wp_share_it_now' ), 
                'ipsitno_manage', 
                'ipsitno',
                array( __CLASS__, 'admin' )
            );
            add_submenu_page( 
                'ipsitno',
                __( 'Add Share Object', 'wp_share_it_now' ), 
                __( 'Add Share Object', 'wp_share_it_now' ), 
                'ipsitno_manage', 
                'ipsitno-add',
                array( __CLASS__, 'admin_add' )
            );
            add_submenu_page( 
                'ipsitno',
                __( 'Coupons', 'wp_share_it_now' ), 
                __( 'Coupons', 'wp_share_it_now' ), 
                'ipsitno_manage', 
                'ipsitno-coupons',
                array( __CLASS__, 'coupons' )
            );
            add_submenu_page( 
                'ipsitno',
                __( 'Users List', 'wp_share_it_now' ), 
                __( 'Users List', 'wp_share_it_now' ), 
                'ipsitno_manage', 
                'ipsitno-users',
                array( __CLASS__, 'users' )
            );
            add_submenu_page( 
                'ipsitno',
                __( 'Settings', 'wp_share_it_now' ), 
                __( 'Settings', 'wp_share_it_now' ), 
                'ipsitno_manage', 
                'ipsitno-setting',
                array( __CLASS__, 'setting' )
            );
        }
        
        /**
         * Admin Init
         *
         * @return void
         */
        public static function admin_init()
        {
            global $wp_roles;
            
            /** 
             * Register Roles
             */
            // Add capability for administrator
            $role = get_role( 'administrator' );
            $role->add_cap( 'ipsitno_manage' );
            
            $wp_roles->reinit();
            
            /**
             * Ajax handler
             **/
            $ajax = new IPSitno_Ajax();
            $ajax->exec();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public static function admin()
        {
            $display = new IPSitno_Admin();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $display->edit();
            } else {
                $display->index();
            }
        }
        
        /**
         * Content for administrator add contest page
         *
         * @return void
         */
        public static function admin_add()
        {
            $display = new IPSitno_Admin();
            $display->add();
        }
        
        /**
         * Content for administrator setting page
         *
         * @return void
         */
        public static function setting()
        {
            $display = new IPSitno_Admin();
            $display->setting();
        }
        
        /**
         * Content for administrator users list page
         *
         * @return void
         */
        public static function users()
        {
            $display = new IPSitno_Admin();
            $display->users();
        }
        
        /**
         * Content for administrator coupons page
         *
         * @return void
         */
        public static function coupons()
        {
            $display = new IPSitno_Admin_Coupon();
            $display->coupons();
        }
        
        /**
         * Share factory
         *
         * @return void
         */
        public static function factory()
        {
            global $ipsitno;
            
            if ( ! $ipsitno ) {
                $ipsitno = new IPSitno_Factory();
            }
            $ipsitno->render();
        }
        
        /**
         * Add administrator meta box
         *
         * @return void
         */
        public static function add_meta_box()
        {
            $screens = array( 'post', 'page' );
            foreach ($screens as $screen) {
                add_meta_box(
                    'ipsitno_metabox',
                    __( 'WP Share It Now Settings', 'wp_share_it_now' ),
                    array( __CLASS__, 'meta_box_content' ),
                    $screen,
                    'side'
                );
            }
        }
        
        /**
         * Content for administrator meta box
         *
         * @return void
         */
        public static function meta_box_content( $post )
        {
            $display = new IPSitno_Admin();
            $display->meta_box( $post );
        }
        
        /**
         * Save page/post meta box setting
         *
         * @return void
         */
        public static function save_page_share( $post_id )
        {
            if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {
                if ( ! current_user_can( 'edit_page', $post_id ) ) {
                    return;
                }
            } else {
                if ( ! current_user_can( 'edit_post', $post_id ) ) {
                    return;
                }
            }
            // Check if the user intended to change this value.
            if ( ! isset( $_POST['ipsitno_mbox_nonce'] ) ) {
                return;
            }
            $post_ID = $_POST['post_ID'];
            $shareId = sanitize_text_field( $_POST['ipsitno_id'] );
            update_post_meta( $post_ID, '__ipsitno_page_share', $shareId );
        }
        
        /**
         * Install plugin
         *
         * @return void
         */
        public static function install()
        {
            //Db
            $db = new IPSitno_Db();
            $db->install();
        }
        
        /**
         * Update database
         *
         * @return void
         */
        public static function update_db()
        {
            $db = new IPSitno_Db();
            $db->update();
        }
        
        /**
         * Main method for create ad button
         *
         * @param  array  $atts
         * @param  string $content
         * @return string
         */
        public static function shortcode( $atts, $content = '')
        {
            $factory = new IPSitno_Shortcode();
            return $factory->factory( $atts, $content );
        }
         
        /**
         * Hook function for add button to editor
         *
         * @return void
         */
        public static function add_editor_button() 
        {
            if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') ) {
                return;
            }
            if ( get_user_option('rich_editing') == 'true') {
                add_filter( 'mce_external_plugins', array( __CLASS__, 'add_tinymce_plugin' ));
                add_filter( 'mce_buttons', array( __CLASS__, 'register_tinymce_button' ));
            }
        }

        /**
         * Register button to TinyMce system
         *
         * @param  array $button
         * @return void
         */
        public static function register_tinymce_button( $buttons ) 
        {
           array_push($buttons, "|", "ipsitnosc");
           return $buttons;
        }

        /**
         * Register TinyMce plugin
         *
         * @param  array $plugin_array
         * @return void
         */
        public static function add_tinymce_plugin( $plugin_array ) 
        {
           $plugin_array['ipsitnosc'] = plugin_dir_url( __FILE__ ) . 'js/editor_plugin.js';
           return $plugin_array;
        }
        
        /**
         * Content editor dialog
         *
         * @return void
         */
        public static function create_editor()
        {
            $display = new IPSitno_Shortcode();
            $display->editor();
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function admin_style()
        {
            wp_deregister_style('insta-backend-style');
            wp_register_style('insta-backend-style', plugin_dir_url( __FILE__ ) . 'css/ipbe-admin.css', false, null);
            wp_enqueue_style('insta-backend-style');
            
            wp_deregister_style('ipsitno-admin-style');
            wp_register_style('ipsitno-admin-style', plugin_dir_url( __FILE__ ) . 'css/admin.css', false, null);
            wp_enqueue_style('ipsitno-admin-style');
            
            wp_deregister_style('ipsitno-public-style');
            wp_register_style('ipsitno-public-style', plugin_dir_url( __FILE__ ) . 'css/public.css', false, null);
            wp_enqueue_style('ipsitno-public-style');
            
            wp_deregister_style('daterangepicker');
            wp_register_style('daterangepicker', plugin_dir_url( __FILE__ ) . 'js/daterangepicker/daterangepicker-bs3.css', false, null);
            wp_enqueue_style('daterangepicker');
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function admin_style_global()
        {
            wp_deregister_style('ipsitno-admin-style-global');
            wp_register_style('ipsitno-admin-style-global', plugin_dir_url( __FILE__ ) . 'css/admin-global.css', false, null);
            wp_enqueue_style('ipsitno-admin-style-global');
        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public static function admin_script($hook)
        {
        ?>
        <script type="text/javascript">
            var ipsitno_img_url = '<?php echo IPSITNO_BASE_URL . 'img/'; ?>',
                ipbe_base       = '<?php echo IPSITNO_BASE_URL; ?>',
                ip_ui_message   = 
                {
                    delete_confirm_title: '<?php _e( 'Delete Confirmation', 'wp_share_it_now' ); ?>',
                    delete_confirm_info: '<?php _e( 'Are you sure doing this action?', 'wp_share_it_now' ); ?>'
                };
        </script>
        <?php
            wp_deregister_script('insta-backend-script');
            wp_enqueue_script(
                'insta-backend-script',
                plugin_dir_url( __FILE__ ) . 'js/ipbe-admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('ipsitno-admin-script');
            wp_enqueue_script(
                'ipsitno-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('moment');
            wp_enqueue_script(
                'moment',
                plugin_dir_url( __FILE__ ) . 'js/daterangepicker/moment.min.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('daterangepicker');
            wp_enqueue_script(
                'daterangepicker',
                plugin_dir_url( __FILE__ ) . 'js/daterangepicker/daterangepicker.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print Global Admin Script
         *
         * @return void
         */
        public static function global_admin_script($hook)
        {
            wp_deregister_script('ipsitno-admin-global-script');
            wp_enqueue_script(
                'ipsitno-admin-global-script',
                plugin_dir_url( __FILE__ ) . 'js/admin-global.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print public style
         *
         * @return void
         */
        public static function public_style()
        {
            global $ipsitno;
            
            if ( ! $ipsitno ) {
                $ipsitno = new IPSitno_Factory();
            }
            $setting = $ipsitno->setting();
            $name    = $setting->getSetting( 'font_family', 'roboto' );
            $fonts   = IPSitno_Font::getLinks();
            if ( array_key_exists( $name, $fonts )) 
            {
                $family  = $fonts[$name];
                $fontUrl = 'http://fonts.googleapis.com/css?family=' . $family;
                echo '<link id="ipsitno-font" href="' . $fontUrl . '" rel="stylesheet" type="text/css">';
            }
        ?>
            <script type="text/javascript">
                var ipsitno_ajaxurl = "<?php echo admin_url( 'admin-ajax.php' ); ?>";
                var ipsitno_scroll  = "<?php echo $setting->getSetting( 'scroll_show', 0 ); ?>";
            </script>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/public.css" rel="stylesheet">
        <?php
        }

        /**
         * Print public script
         *
         * @return void
         */
        public static function public_script()
        {
            wp_enqueue_script('jquery');
            
            wp_deregister_script('jquery-ui');
            wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js", false, null);
            wp_enqueue_script('jquery-ui');
            
            wp_deregister_script('ipsitno-public-script');
            wp_enqueue_script(
                'ipsitno-public-script',
                plugin_dir_url( __FILE__ ) . 'js/public.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }
    }

}
//Run plugin
IPSitno::setup();
?>